@@ -26,7 +26,7 @@ class MiniECS:
         self.port = port
         self.sock = socket.create_connection((address, port))
 
-    def create_container(self, name: str) -> tuple(bool, str):
+    def create_container(self, name: str):
 
         response = (False, "None")
 
